@@ -196,7 +196,6 @@ void check_title(const T_Item& item, const char* title_en, const char* title_de)
     //Check that fallbacks do not happen when we don't want them:
     g_assert( item->get_title_translation(Glib::ustring(), false) == Glib::ustring() );
     g_assert( item->get_title_translation("en_US", false) == Glib::ustring() );
-    g_assert( item->get_title_translation("en_GB", false) == Glib::ustring() );
     g_assert( item->get_title_translation("de_AU", false) == Glib::ustring() );
   }
 }
@@ -243,7 +242,7 @@ int main()
   }
 
   const std::vector<Glib::ustring> locales = document.get_translation_available_locales();
-  g_assert(locales.size() == 9);
+  g_assert(locales.size() == 12);
   g_assert(contains(locales, "de"));
 
   const std::vector<Glib::ustring> table_names = document.get_table_names();
@@ -338,9 +337,15 @@ int main()
   const bool contains_customtitle =
     contains_item_type<Glom::CustomTitle>(list_layout_items);
   g_assert( contains_customtitle );
+  const bool contains_static_text =
+    contains_item_type<Glom::LayoutItem_Text>(list_layout_items);
+  g_assert( contains_static_text );
   const bool contains_report =
     contains_item_type<Glom::Report>(list_layout_items);
   g_assert( contains_report );
+  const bool contains_print_layout =
+    contains_item_type<Glom::PrintLayout>(list_layout_items);
+  g_assert( contains_print_layout );
 
   Glom::libglom_deinit();
 
